# pyhtmlchart 1.1

![Logo](https://sid72020123.github.io/pyhtmlchart/logo.svg)

pyhtmlchart is a Python library to make Google Charts.

![https://img.shields.io/badge/Python-3776AB?style=for-the-badge&logo=python&logoColor=white](https://img.shields.io/badge/Python-3776AB?style=for-the-badge&logo=python&logoColor=white)

[![PyPI Latest Release](https://img.shields.io/pypi/v/pyhtmlchart.svg)](https://pypi.org/project/pyhtmlchart/)
[![Package Status](https://img.shields.io/pypi/status/pyhtmlchart.svg)](https://pypi.org/project/pyhtmlchart/)
[![Downloads](https://static.pepy.tech/personalized-badge/pyhtmlchart?period=total&units=international_system&left_color=black&right_color=orange&left_text=Downloads)](https://pepy.tech/project/pyhtmlchart)

## Documentation:

For documentation(tutorial), go
to [https://sid72020123.github.io/pyhtmlchart/](https://sid72020123.github.io/pyhtmlchart/)

# Thanks to Google Charts
